pub struct ValidSignatureResponse {
pub is_valid: bool,
}Fields
is_valid: boolTrait Implementations
Sourceimpl Clone for ValidSignatureResponse
impl Clone for ValidSignatureResponse
Sourcefn clone(&self) -> ValidSignatureResponse
fn clone(&self) -> ValidSignatureResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidSignatureResponse
impl Debug for ValidSignatureResponse
Sourceimpl<'de> Deserialize<'de> for ValidSignatureResponse
impl<'de> Deserialize<'de> for ValidSignatureResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidSignatureResponse
impl JsonSchema for ValidSignatureResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ValidSignatureResponse
impl PartialEq for ValidSignatureResponse
Sourceimpl Serialize for ValidSignatureResponse
impl Serialize for ValidSignatureResponse
impl StructuralPartialEq for ValidSignatureResponse