pub struct ValidSignaturesResponse {
pub are_valid: Vec<bool>,
}Fields
are_valid: Vec<bool>Trait Implementations
Sourceimpl Clone for ValidSignaturesResponse
impl Clone for ValidSignaturesResponse
Sourcefn clone(&self) -> ValidSignaturesResponse
fn clone(&self) -> ValidSignaturesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidSignaturesResponse
impl Debug for ValidSignaturesResponse
Sourceimpl<'de> Deserialize<'de> for ValidSignaturesResponse
impl<'de> Deserialize<'de> for ValidSignaturesResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidSignaturesResponse
impl JsonSchema for ValidSignaturesResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ValidSignaturesResponse
impl PartialEq for ValidSignaturesResponse
Sourceimpl Serialize for ValidSignaturesResponse
impl Serialize for ValidSignaturesResponse
impl StructuralPartialEq for ValidSignaturesResponse